/*
 *  This file is part of uIRC. (https://git.redxen.eu/caskd/uIRC)
 *  Copyright (c) 2019-2021 Alex-David Denes
 *
 *  uIRC is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  any later version.
 *
 *  uIRC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with uIRC.  If not, see <https://www.gnu.org/licenses/>.
 */

/*! \file */

#include "type.h" // IRC_User IRC_Message

#include <corelibs/llist.h> // llist_t
#include <sys/types.h>      // ssize_t ssize_t

#ifndef UIRC_GUARD_PUBLIC_ASSEMBLERS
#define UIRC_GUARD_PUBLIC_ASSEMBLERS

ssize_t uirc_assembler_user(char* buf, const IRC_User* u, size_t len);

#ifdef UIRC_FEATURE_IRCV3
ssize_t uirc_assembler_tag(char* buf, const IRC_Tag* t, size_t len);
ssize_t uirc_assembler_tag_list(char* buf, const llist_t* t, size_t len);
#endif /* UIRC_FEATURE_IRCV3*/

/*!
 * \brief IRC_Message to string converter
 *
 * This assembles a IRC_Message struct to a string representation of a most size len
 * The return value is either the lenght of the string or any of the uirc_errors errors
 * \param[out] buf String representation of message
 * \param[in] m IRC_Message struct that contains at least a command
 * \param[in] len Maximum lenght of string
 * \warning in and buf SHOULD NOT be NULL
 */
ssize_t uirc_assembler_message(char* buf, const IRC_Message* m, size_t len);
#endif /* UIRC_GUARD_PUBLIC_ASSEMBLERS */

